/*
 *  This file is part of athena-ssl-cipher-check.
 *
 *  athena-ssl-cipher-check is free software: you can redistribute it
 *  and/or modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation, either version 3 of the License,
 *  or (at your option) any later version.
 *
 *  athena-ssl-cipher-check is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with athena-ssl-cipher-check. If not, see
 *  <http://www.gnu.org/licenses/>.
 *
 */

package athenasslciphercheck;

public class ssl2CipherCheck {
    
    String host;
    int port;

    public int resetCount = 0;
    public int timedOutCount = 0;
    public int unidentifiedCount = 0;
    public int rejectedCount = 0;

    ssl2CipherCheck(String host, int port)
    {
        this.port = port;
        this.host = host;
    }

    public void check()
    {
        byte[] helloMessage = new byte[30];

        byte[] cipherSpec = { (byte) 0x01, (byte) 0x00, (byte) 0x80,   //SSL_CK_RC4_128_WITH_MD5
                              (byte) 0x02, (byte) 0x00, (byte) 0x80,   //SSL_CK_RC4_128_EXPORT40_WITH_MD5
                              (byte) 0x03, (byte) 0x00, (byte) 0x80,   //SSL_CK_RC2_128_CBC_WITH_MD5
                              (byte) 0x04, (byte) 0x00, (byte) 0x80,   //SSL_CK_RC2_128_CBC_EXPORT40_WITH_MD5
                              (byte) 0x05, (byte) 0x00, (byte) 0x80,   //SSL_CK_IDEA_128_CBC_WITH_MD5
                              (byte) 0x06, (byte) 0x00, (byte) 0x40,   //SSL_CK_DES_64_CBC_WITH_MD5
                              (byte) 0x07, (byte) 0x00, (byte) 0xC0 }; //SSL_CK_DES_192_EDE3_CBC_WITH_MD5

        int timeOutCounter = 0;
        
        for( int i = 0; i < 7; i++ )
        {
            sslv2MessageFactory.makeMessage( helloMessage, cipherSpec, i*3 );
            connection conn = new connection();
            if( !conn.connect(host, port) )
            {
                break;
            }

            conn.send(helloMessage);

            int tmp = 0x00;

            for( int n = 0; n < 11; n++ )
            {
                tmp = conn.recv();
                if( tmp == -3 )
                {
                    timeOutCounter++;
                    if( false /*timeOutCounter > 3*/ )
                    {
                        System.out.println("SSLv2 being skipped due to timeouts");
                        return;
                    }
                    break;
                }
            }

            if( tmp == 0x03 )
            {
                switch( cipherSpec[i*3] )
                {
                    case 0x01:
                        System.out.println("SSL_CK_RC4_128_WITH_MD5");
                        break;
                    case 0x02:
                        System.out.println("SSL_CK_RC4_128_EXPORT40_WITH_MD5");
                        break;
                    case 0x03:
                        System.out.println("SSL_CK_RC2_128_CBC_WITH_MD5");
                        break;
                    case 0x04:
                        System.out.println("SSL_CK_RC2_128_CBC_EXPORT40_WITH_MD5");
                        break;
                    case 0x05:
                        System.out.println("SSL_CK_IDEA_128_CBC_WITH_MD5");
                        break;
                    case 0x06:
                        System.out.println("SSL_CK_DES_64_CBC_WITH_MD5");
                        break;
                    case 0x07:
                        System.out.println("SSL_CK_DES_192_EDE3_CBC_WITH_MD5");
                        break;
                    default:
                        System.err.println("Unknown SSLv2 Cipher found");
                }
            }

            conn.close();
        }
    }

    private void printStats() {
        if( resetCount == 0 &&
            timedOutCount == 0 &&
            unidentifiedCount == 0 &&
            rejectedCount == 0 )
            return;

        System.out.println("");
        boolean first = true;
        if( resetCount > 0 )
        {
            System.out.print(resetCount + " connections reset");
            first = false;
        }

        if( timedOutCount > 0 )
        {
            if( !first )
                System.out.print(", ");
            System.out.print(resetCount + " connections reset");
            first = false;
        }

        if( unidentifiedCount > 0 )
        {
            if( !first )
                System.out.print(", ");
            System.out.print(unidentifiedCount + " connections reset");
            first = false;
        }

        if( rejectedCount > 0 )
        {
            if( !first )
                System.out.print(", ");
            System.out.print(rejectedCount + " connections reset");
            first = false;
        }
    }
}
